for i in [1,2,3]:
    print(i)


print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
print("yo")
